##  Implementation Details
Users provide SAP LeanIX with credentials that have the needed permission to connect with the integration. Once connected, SAP LeanIX periodically pulls data from the [Discovery Apps API![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdeveloper.walkme.com%2Freference%2Fdiscovery-apps-api "https://developer.walkme.com/reference/discovery-apps-api"), specifically calling the /public/v1/discovery/getCustomerAppsStats endpoint.
WalkMe aggregates usage data per calendar month, and for the ongoing month, the usage data includes activity only up to the current date. To ensure consistency, SAP LeanIX pulls and displays usage data only for the previous completed month.
Authentication Mechanism | Supported Regions | API Endpoints Used | WalkMe resource
---|---|---|---
REST API [OAuth![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdeveloper.walkme.com%2Freference%2Fgetting-started-with-your-api-1 "https://developer.walkme.com/reference/getting-started-with-your-api-1") |  [Global![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdeveloper.walkme.com%2Freference%2Fgetting-started-with-your-api%23api-base-url "https://developer.walkme.com/reference/getting-started-with-your-api#api-base-url") |  For API authentication: /accounts/connect/token For SaaS discovery: /public/v1/discovery/getCustomerAppsStats |  [Discovery Apps API![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdeveloper.walkme.com%2Freference%2Fdiscovery-apps-api "https://developer.walkme.com/reference/discovery-apps-api")


